@@ -93,77 +93,6 @@ ags_line_group_clicked_callback(GtkWidget *widget, AgsLine *line)
   }
 
   g_list_free(list_start);
-
-  return;
-}
-
-void
-ags_line_volume_callback(GtkRange *range,
-			 AgsLine *line)
-{
-  AgsVolumeChannel *volume_channel;
-
-  GList *start_list, *list;
-  
-  GValue value = {0,};
-
-  g_value_init(&value,
-	       G_TYPE_DOUBLE);
-
-  g_value_set_double(&value,
-		     gtk_range_get_value(range));
-
-  /* play context */
-  g_object_get(line->channel,
-	       "play", &start_list,
-	       NULL);
-
-  list = start_list;
-  
-  while((list = ags_recall_find_type(list, AGS_TYPE_VOLUME_CHANNEL)) != NULL){
-    AgsPort *port;
-    
-    volume_channel = AGS_VOLUME_CHANNEL(list->data);
-
-    g_object_get(volume_channel,
-		 "volume", &port,
-		 NULL);
-    
-    ags_port_safe_write(port,
-			&value);
-
-    /* iterate */
-    list = list->next;
-  }
-
-  g_list_free_full(start_list,
-		   g_object_unref);
-  
-  /* recall context */
-  g_object_get(line->channel,
-	       "recall", &start_list,
-	       NULL);
-
-  list = start_list;
-
-  while((list = ags_recall_find_type(list, AGS_TYPE_VOLUME_CHANNEL)) != NULL){
-    AgsPort *port;
-    
-    volume_channel = AGS_VOLUME_CHANNEL(list->data);
-
-    g_object_get(volume_channel,
-		 "volume", &port,
-		 NULL);
-    
-    ags_port_safe_write(port,
-			&value);
-
-    /* iterate */
-    list = list->next;
-  }
-
-  g_list_free_full(start_list,
-		   g_object_unref);
 }
 
 void
