@@ -75,8 +75,9 @@ ags_machine_parent_set_callback(GtkWidget *widget, GtkWidget *old_parent, AgsMac
 							  i);
 
       if(audio_thread != NULL){
-	ags_audio_thread_set_do_fx_staging(audio_thread, TRUE);
-	ags_audio_thread_set_staging_program(audio_thread,
+	ags_audio_thread_set_do_fx_staging((AgsAudioThread *) audio_thread,
+					   TRUE);
+	ags_audio_thread_set_staging_program((AgsAudioThread *) audio_thread,
 					     staging_program,
 					     1);
 	    
@@ -238,13 +239,21 @@ ags_machine_map_recall_callback(AgsMachine *machine,
 int
 ags_machine_button_press_callback(GtkWidget *handle_box, GdkEventButton *event, AgsMachine *machine)
 {
-  AgsWindow *window = AGS_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET(handle_box)));
-
   if(event->button == 3){
-    gtk_menu_popup (GTK_MENU (machine->popup),
-                    NULL, NULL, NULL, NULL,
-                    event->button, event->time);
+    gtk_menu_popup_at_widget(GTK_MENU(machine->popup),
+			     handle_box,
+			     GDK_GRAVITY_SOUTH_EAST,
+			     GDK_GRAVITY_NORTH_WEST,
+			     NULL);
   }else if(event->button == 1){
+    AgsWindow *window;
+
+    AgsApplicationContext *application_context;
+
+    application_context = ags_application_context_get_instance();
+    
+    window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
+    
     window->selected = machine;
   }
 
@@ -254,9 +263,10 @@ ags_machine_button_press_callback(GtkWidget *handle_box, GdkEventButton *event,
 void
 ags_machine_popup_move_up_activate_callback(GtkWidget *widget, AgsMachine *machine)
 {
-  GValue val={0,};
+  GValue val = G_VALUE_INIT;
 
-  g_value_init (&val, G_TYPE_INT);
+  g_value_init(&val,
+	       G_TYPE_INT);
 
   gtk_container_child_get_property(GTK_CONTAINER(gtk_widget_get_parent(GTK_WIDGET(machine))),
 				   GTK_WIDGET(machine),
@@ -403,15 +413,13 @@ ags_machine_popup_rename_activate_callback(GtkWidget *widget, AgsMachine *machin
     dialog = (GtkDialog *) gtk_dialog_new_with_buttons(i18n("rename"),
 						       (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(machine)),
 						       GTK_DIALOG_DESTROY_WITH_PARENT,
-						       GTK_STOCK_OK,
-						       GTK_RESPONSE_ACCEPT,
-						       GTK_STOCK_CANCEL,
-						       GTK_RESPONSE_REJECT,
+						       "_OK", GTK_RESPONSE_ACCEPT,
+						       "_Cancel", GTK_RESPONSE_REJECT,
 						       NULL);
 
   entry = (GtkEntry *) gtk_entry_new();
   gtk_entry_set_text(entry, machine->machine_name);
-  gtk_box_pack_start(gtk_dialog_get_content_area(dialog),
+  gtk_box_pack_start((GtkBox *) gtk_dialog_get_content_area(dialog),
 		     (GtkWidget *) entry,
 		     FALSE, FALSE,
 		     0);
@@ -467,10 +475,8 @@ ags_machine_popup_rename_audio_activate_callback(GtkWidget *widget, AgsMachine *
     dialog = (GtkDialog *) gtk_dialog_new_with_buttons(i18n("rename audio"),
 						       (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(machine)),
 						       GTK_DIALOG_DESTROY_WITH_PARENT,
-						       GTK_STOCK_OK,
-						       GTK_RESPONSE_ACCEPT,
-						       GTK_STOCK_CANCEL,
-						       GTK_RESPONSE_REJECT,
+						       "_OK", GTK_RESPONSE_ACCEPT,
+						       "_Cancel", GTK_RESPONSE_REJECT,
 						       NULL);
 
   g_object_get(audio,
@@ -550,10 +556,8 @@ ags_machine_popup_reposition_audio_activate_callback(GtkWidget *widget, AgsMachi
     dialog = (GtkDialog *) gtk_dialog_new_with_buttons(i18n("reposition audio"),
 						       (GtkWindow *) gtk_widget_get_toplevel(GTK_WIDGET(machine)),
 						       GTK_DIALOG_DESTROY_WITH_PARENT,
-						       GTK_STOCK_OK,
-						       GTK_RESPONSE_ACCEPT,
-						       GTK_STOCK_CANCEL,
-						       GTK_RESPONSE_REJECT,
+						       "_OK", GTK_RESPONSE_ACCEPT,
+						       "_Cancel", GTK_RESPONSE_REJECT,
 						       NULL);
 
   if(position >= 0){
@@ -910,8 +914,9 @@ ags_machine_resize_audio_channels_callback(AgsMachine *machine,
 							     i);
 
 	    if(channel_thread != NULL){
-	      ags_channel_thread_set_do_fx_staging(channel_thread, TRUE);
-	      ags_channel_thread_set_staging_program(channel_thread,
+	      ags_channel_thread_set_do_fx_staging((AgsChannelThread *) channel_thread,
+						   TRUE);
+	      ags_channel_thread_set_staging_program((AgsChannelThread *) channel_thread,
 						     staging_program,
 						     1);
 	    
@@ -975,8 +980,9 @@ ags_machine_resize_audio_channels_callback(AgsMachine *machine,
 							     i);
 
 	    if(channel_thread != NULL){
-	      ags_channel_thread_set_do_fx_staging(channel_thread, TRUE);
-	      ags_channel_thread_set_staging_program(channel_thread,
+	      ags_channel_thread_set_do_fx_staging((AgsChannelThread *) channel_thread,
+						   TRUE);
+	      ags_channel_thread_set_staging_program((AgsChannelThread *) channel_thread,
 						     staging_program,
 						     1);
 	    
@@ -1066,7 +1072,7 @@ ags_machine_resize_pads_callback(AgsMachine *machine,
   AgsPlayback *playback;
   AgsChannel *start_output;
   AgsChannel *start_input;
-  AgsChannel *channel, *next_pad, *next_channel;
+  AgsChannel *channel, *next_channel;
 
   GList *pad_list;
 
@@ -1110,8 +1116,9 @@ ags_machine_resize_pads_callback(AgsMachine *machine,
 							     i);
 
 	    if(channel_thread != NULL){
-	      ags_channel_thread_set_do_fx_staging(channel_thread, TRUE);
-	      ags_channel_thread_set_staging_program(channel_thread,
+	      ags_channel_thread_set_do_fx_staging((AgsChannelThread *) channel_thread,
+						   TRUE);
+	      ags_channel_thread_set_staging_program((AgsChannelThread *) channel_thread,
 						     staging_program,
 						     1);
 	    
@@ -1164,8 +1171,9 @@ ags_machine_resize_pads_callback(AgsMachine *machine,
 							     i);
 
 	    if(channel_thread != NULL){
-	      ags_channel_thread_set_do_fx_staging(channel_thread, TRUE);
-	      ags_channel_thread_set_staging_program(channel_thread,
+	      ags_channel_thread_set_do_fx_staging((AgsChannelThread *) channel_thread,
+						   TRUE);
+	      ags_channel_thread_set_staging_program((AgsChannelThread *) channel_thread,
 						     staging_program,
 						     1);
 	    
