@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2020 Joël Krähemann
+ * Copyright (C) 2005-2021 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -77,7 +77,7 @@ struct _AgsSyncsynth
   AgsRecallContainer *buffer_play_container;
   AgsRecallContainer *buffer_recall_container;
   
-  GtkVBox *oscillator;
+  GtkBox *oscillator;
   GtkButton *add;
   GtkButton *remove;
   
