@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2019 Joël Krähemann
+ * Copyright (C) 2005-2021 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -63,14 +63,14 @@ void ags_fm_synth_util_sin_s64(gint64 *buffer,
 			       guint lfo_osc_mode,
 			       gdouble lfo_freq, gdouble lfo_depth,
 			       gdouble tuning);
-void ags_fm_synth_util_sin_float(float *buffer,
+void ags_fm_synth_util_sin_float(gfloat *buffer,
 				 gdouble freq, gdouble phase, gdouble volume,
 				 guint samplerate,
 				 guint offset, guint n_frames,
 				 guint lfo_osc_mode,
 				 gdouble lfo_freq, gdouble lfo_depth,
 				 gdouble tuning);
-void ags_fm_synth_util_sin_double(double *buffer,
+void ags_fm_synth_util_sin_double(gdouble *buffer,
 				  gdouble freq, gdouble phase, gdouble volume,
 				  guint samplerate,
 				  guint offset, guint n_frames,
@@ -121,14 +121,14 @@ void ags_fm_synth_util_sawtooth_s64(gint64 *buffer,
 				    guint lfo_osc_mode,
 				    gdouble lfo_freq, gdouble lfo_depth,
 				    gdouble tuning);
-void ags_fm_synth_util_sawtooth_float(float *buffer,
+void ags_fm_synth_util_sawtooth_float(gfloat *buffer,
 				      gdouble freq, gdouble phase, gdouble volume,
 				      guint samplerate,
 				      guint offset, guint n_frames,
 				      guint lfo_osc_mode,
 				      gdouble lfo_freq, gdouble lfo_depth,
 				      gdouble tuning);
-void ags_fm_synth_util_sawtooth_double(double *buffer,
+void ags_fm_synth_util_sawtooth_double(gdouble *buffer,
 				       gdouble freq, gdouble phase, gdouble volume,
 				       guint samplerate,
 				       guint offset, guint n_frames,
@@ -179,14 +179,14 @@ void ags_fm_synth_util_triangle_s64(gint64 *buffer,
 				    guint lfo_osc_mode,
 				    gdouble lfo_freq, gdouble lfo_depth,
 				    gdouble tuning);
-void ags_fm_synth_util_triangle_float(float *buffer,
+void ags_fm_synth_util_triangle_float(gfloat *buffer,
 				      gdouble freq, gdouble phase, gdouble volume,
 				      guint samplerate,
 				      guint offset, guint n_frames,
 				      guint lfo_osc_mode,
 				      gdouble lfo_freq, gdouble lfo_depth,
 				      gdouble tuning);
-void ags_fm_synth_util_triangle_double(double *buffer,
+void ags_fm_synth_util_triangle_double(gdouble *buffer,
 				       gdouble freq, gdouble phase, gdouble volume,
 				       guint samplerate,
 				       guint offset, guint n_frames,
@@ -237,14 +237,14 @@ void ags_fm_synth_util_square_s64(gint64 *buffer,
 				  guint lfo_osc_mode,
 				  gdouble lfo_freq, gdouble lfo_depth,
 				  gdouble tuning);
-void ags_fm_synth_util_square_float(float *buffer,
+void ags_fm_synth_util_square_float(gfloat *buffer,
 				    gdouble freq, gdouble phase, gdouble volume,
 				    guint samplerate,
 				    guint offset, guint n_frames,
 				    guint lfo_osc_mode,
 				    gdouble lfo_freq, gdouble lfo_depth,
 				    gdouble tuning);
-void ags_fm_synth_util_square_double(double *buffer,
+void ags_fm_synth_util_square_double(gdouble *buffer,
 				     gdouble freq, gdouble phase, gdouble volume,
 				     guint samplerate,
 				     guint offset, guint n_frames,
@@ -295,14 +295,14 @@ void ags_fm_synth_util_impulse_s64(gint64 *buffer,
 				   guint lfo_osc_mode,
 				   gdouble lfo_freq, gdouble lfo_depth,
 				   gdouble tuning);
-void ags_fm_synth_util_impulse_float(float *buffer,
+void ags_fm_synth_util_impulse_float(gfloat *buffer,
 				     gdouble freq, gdouble phase, gdouble volume,
 				     guint samplerate,
 				     guint offset, guint n_frames,
 				     guint lfo_osc_mode,
 				     gdouble lfo_freq, gdouble lfo_depth,
 				     gdouble tuning);
-void ags_fm_synth_util_impulse_double(double *buffer,
+void ags_fm_synth_util_impulse_double(gdouble *buffer,
 				      gdouble freq, gdouble phase, gdouble volume,
 				      guint samplerate,
 				      guint offset, guint n_frames,
