@@ -22,7 +22,7 @@
 #include <ags/audio/ags_synth_enums.h>
 #include <ags/audio/ags_audio_signal.h>
 #include <ags/audio/ags_audio_buffer_util.h>
-#include <ags/audio/ags_fast_pitch_util.h>
+#include <ags/audio/ags_hq_pitch_util.h>
 
 #include <ags/audio/file/ags_sound_container.h>
 #include <ags/audio/file/ags_sound_resource.h>
@@ -360,11 +360,11 @@ ags_sf2_synth_util_copy_s8(gint8 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_s8(im_buffer,
-				 frame_count,
-				 samplerate,
-				 base_key,
-				 tuning);
+  ags_hq_pitch_util_compute_s8(im_buffer,
+			       frame_count,
+			       samplerate,
+			       base_key,
+			       tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -635,11 +635,11 @@ ags_sf2_synth_util_copy_s16(gint16 *buffer,
 
   tuning = 100.0 * (note - base_key);
 
-  ags_fast_pitch_util_compute_s16(im_buffer,
-				  frame_count,
-				  samplerate,
-				  base_key,
-				  tuning);
+  ags_hq_pitch_util_compute_s16(im_buffer,
+				frame_count,
+				samplerate,
+				base_key,
+				tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -910,11 +910,11 @@ ags_sf2_synth_util_copy_s24(gint32 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_s24(im_buffer,
-				  frame_count,
-				  samplerate,
-				  base_key,
-				  tuning);
+  ags_hq_pitch_util_compute_s24(im_buffer,
+				frame_count,
+				samplerate,
+				base_key,
+				tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1185,11 +1185,11 @@ ags_sf2_synth_util_copy_s32(gint32 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_s32(im_buffer,
-				  frame_count,
-				  samplerate,
-				  base_key,
-				  tuning);
+  ags_hq_pitch_util_compute_s32(im_buffer,
+				frame_count,
+				samplerate,
+				base_key,
+				tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1460,11 +1460,11 @@ ags_sf2_synth_util_copy_s64(gint64 *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_s64(im_buffer,
-				  frame_count,
-				  samplerate,
-				  base_key,
-				  tuning);
+  ags_hq_pitch_util_compute_s64(im_buffer,
+				frame_count,
+				samplerate,
+				base_key,
+				tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -1735,11 +1735,11 @@ ags_sf2_synth_util_copy_float(gfloat *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_float(im_buffer,
-				    frame_count,
-				    samplerate,
-				    base_key,
-				    tuning);
+  ags_hq_pitch_util_compute_float(im_buffer,
+				  frame_count,
+				  samplerate,
+				  base_key,
+				  tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -2010,11 +2010,11 @@ ags_sf2_synth_util_copy_double(gdouble *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_double(im_buffer,
-				     frame_count,
-				     samplerate,
-				     base_key,
-				     tuning);
+  ags_hq_pitch_util_compute_double(im_buffer,
+				   frame_count,
+				   samplerate,
+				   base_key,
+				   tuning);
 
   success = FALSE;
   pong_copy = FALSE;
@@ -2285,11 +2285,11 @@ ags_sf2_synth_util_copy_complex(AgsComplex *buffer,
 
   tuning = 100.0 * (note - base_key);
   
-  ags_fast_pitch_util_compute_complex(im_buffer,
-				      frame_count,
-				      samplerate,
-				      base_key,
-				      tuning);
+  ags_hq_pitch_util_compute_complex(im_buffer,
+				    frame_count,
+				    samplerate,
+				    base_key,
+				    tuning);
 
   success = FALSE;
   pong_copy = FALSE;
