@@ -54,6 +54,10 @@ ags_buffer_util_s8_to_char_buffer(gint8 *buffer,
 
   guint limit;
   guint i;
+
+  if(buffer == NULL){
+    return(NULL);
+  }
   
   start_cbuffer = 
     cbuffer = (guchar *) malloc(buffer_length * sizeof(guchar));
@@ -107,6 +111,10 @@ ags_buffer_util_s16_to_char_buffer(gint16 *buffer,
 
   guint limit;
   guint i;
+
+  if(buffer == NULL){
+    return(NULL);
+  }
   
   start_cbuffer = 
     cbuffer = (guchar *) malloc((2 * buffer_length) * sizeof(guchar));
@@ -176,6 +184,10 @@ ags_buffer_util_s24_to_char_buffer(gint32 *buffer,
 
   guint limit;
   guint i;
+
+  if(buffer == NULL){
+    return(NULL);
+  }
   
   start_cbuffer = 
     cbuffer = (guchar *) malloc((4 * buffer_length) * sizeof(guchar));
@@ -263,6 +275,10 @@ ags_buffer_util_s32_to_char_buffer(gint32 *buffer,
 
   guint limit;
   guint i;
+
+  if(buffer == NULL){
+    return(NULL);
+  }
   
   start_cbuffer = 
     cbuffer = (guchar *) malloc((4 * buffer_length) * sizeof(guchar));
@@ -350,6 +366,10 @@ ags_buffer_util_s64_to_char_buffer(gint64 *buffer,
 
   guint limit;
   guint i;
+
+  if(buffer == NULL){
+    return(NULL);
+  }
   
   start_cbuffer = 
     cbuffer = (guchar *) malloc((8 * buffer_length) * sizeof(guchar));
@@ -470,6 +490,10 @@ ags_buffer_util_float_to_char_buffer(gfloat *buffer,
 				     guint buffer_length)
 {
   guchar *cbuffer, *start_cbuffer;
+
+  if(buffer == NULL){
+    return(NULL);
+  }
   
   start_cbuffer = 
     cbuffer = (guchar *) malloc((buffer_length * sizeof(gfloat)) * sizeof(guchar));
@@ -496,6 +520,10 @@ ags_buffer_util_double_to_char_buffer(gdouble *buffer,
 {
   guchar *cbuffer, *start_cbuffer;
 
+  if(buffer == NULL){
+    return(NULL);
+  }
+
   start_cbuffer = 
     cbuffer = (guchar *) malloc((buffer_length * sizeof(gdouble)) * sizeof(guchar));
 
@@ -521,6 +549,10 @@ ags_buffer_util_complex_to_char_buffer(AgsComplex *buffer,
 {
   guchar *cbuffer, *start_cbuffer;
 
+  if(buffer == NULL){
+    return(NULL);
+  }
+
   start_cbuffer = 
     cbuffer = (guchar *) malloc((buffer_length * sizeof(AgsComplex)) * sizeof(guchar));
 
@@ -549,6 +581,10 @@ ags_buffer_util_char_buffer_to_s8(guchar *cbuffer,
   guint limit;
   guint i;
 
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gint8 *) malloc(buffer_size * sizeof(gint8));
   memset(buffer, 0, buffer_size * sizeof(gint8));
@@ -603,6 +639,10 @@ ags_buffer_util_char_buffer_to_s16(guchar *cbuffer,
   guint limit;
   guint i;
 
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gint16 *) malloc((buffer_size / 2) * sizeof(gint16));
   memset(buffer, 0, (buffer_size / 2) * sizeof(gint16));
@@ -675,6 +715,10 @@ ags_buffer_util_char_buffer_to_s24(guchar *cbuffer,
   guint limit;
   guint i;
 
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gint32 *) malloc((buffer_size / 4) * sizeof(gint32));
   memset(buffer, 0, (buffer_size / 4) * sizeof(gint32));
@@ -765,6 +809,10 @@ ags_buffer_util_char_buffer_to_s32(guchar *cbuffer,
   guint limit;
   guint i;
   
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gint32 *) malloc((buffer_size / 4) * sizeof(gint32));
   memset(buffer, 0, (buffer_size / 4) * sizeof(gint32));
@@ -855,6 +903,10 @@ ags_buffer_util_char_buffer_to_s64(guchar *cbuffer,
   guint limit;
   guint i;
 
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gint64 *) malloc((buffer_size / 8) * sizeof(gint64));
   memset(buffer, 0, (buffer_size / 8) * sizeof(gint64));
@@ -978,6 +1030,10 @@ ags_buffer_util_char_buffer_to_float(guchar *cbuffer,
 {
   gfloat *buffer, *start_buffer;
   
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gfloat *) malloc((buffer_size / sizeof(gfloat)) * sizeof(gfloat));
 
@@ -1005,6 +1061,10 @@ ags_buffer_util_char_buffer_to_double(guchar *cbuffer,
 {
   gdouble *buffer, *start_buffer;
   
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (gdouble *) malloc((buffer_size / sizeof(gdouble)) * sizeof(gdouble));
 
@@ -1032,6 +1092,10 @@ ags_buffer_util_char_buffer_to_complex(guchar *cbuffer,
 {
   AgsComplex *buffer, *start_buffer;
   
+  if(cbuffer == NULL){
+    return(NULL);
+  }
+
   start_buffer = 
     buffer = (AgsComplex *) malloc((buffer_size / sizeof(AgsComplex)) * sizeof(AgsComplex));
 
@@ -1059,6 +1123,10 @@ ags_buffer_util_char_buffer_read_s8(guchar *cbuffer,
 {
   gint8 val;
 
+  if(cbuffer == NULL){
+    return(0);
+  }
+
   val = 0;
   val |= cbuffer[0];
 
@@ -1082,6 +1150,10 @@ ags_buffer_util_char_buffer_read_s16(guchar *cbuffer,
 {
   gint16 val;
 
+  if(cbuffer == NULL){
+    return(0);
+  }
+
   val = 0;
   
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1112,6 +1184,10 @@ ags_buffer_util_char_buffer_read_s24(guchar *cbuffer,
 {
   gint32 val;
 
+  if(cbuffer == NULL){
+    return(0);
+  }
+
   val = 0;
   
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1144,6 +1220,10 @@ ags_buffer_util_char_buffer_read_s32(guchar *cbuffer,
 {
   gint32 val;
 
+  if(cbuffer == NULL){
+    return(0);
+  }
+
   val = 0;
   
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1178,6 +1258,10 @@ ags_buffer_util_char_buffer_read_s64(guchar *cbuffer,
 {
   gint64 val;
 
+  if(cbuffer == NULL){
+    return(0);
+  }
+
   val = 0;
   
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1222,6 +1306,10 @@ ags_buffer_util_char_buffer_read_float(guchar *cbuffer,
     guint32 val;
     GFloatIEEE754 ieee_float;
   }data;
+
+  if(cbuffer == NULL){
+    return(0.0);
+  }
   
   data.val = 0;
   
@@ -1260,6 +1348,10 @@ ags_buffer_util_char_buffer_read_double(guchar *cbuffer,
     GDoubleIEEE754 ieee_double;
   }data;
 
+  if(cbuffer == NULL){
+    return(0.0);
+  }
+
   data.val = 0;
   
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1306,6 +1398,10 @@ ags_buffer_util_char_buffer_read_complex(guchar *cbuffer,
   }data;
 
   guint i;
+
+  if(cbuffer == NULL){
+    return(NULL);
+  }
   
   for(i = 0; i < sizeof(AgsComplex); i++){
     if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1333,6 +1429,10 @@ ags_buffer_util_char_buffer_write_s8(guchar *cbuffer,
 				     gint8 value,
 				     guint byte_order)
 {
+  if(cbuffer == NULL){
+    return;
+  }
+  
   cbuffer[0] = value;
 }
 
@@ -1351,6 +1451,10 @@ ags_buffer_util_char_buffer_write_s16(guchar *cbuffer,
 				      gint16 value,
 				      guint byte_order)
 {
+  if(cbuffer == NULL){
+    return;
+  }
+
   if(byte_order == AGS_BYTE_ORDER_BE){
     cbuffer[0] = (0xff & value);
     cbuffer[1] = (0xff00 & value) >> 8;
@@ -1375,6 +1479,10 @@ ags_buffer_util_char_buffer_write_s24(guchar *cbuffer,
 				      gint32 value,
 				      guint byte_order)
 {
+  if(cbuffer == NULL){
+    return;
+  }
+
   if(byte_order == AGS_BYTE_ORDER_BE){
     cbuffer[0] = (0xff & value);
     cbuffer[1] = (0xff00 & value) >> 8;
@@ -1401,6 +1509,10 @@ ags_buffer_util_char_buffer_write_s32(guchar *cbuffer,
 				      gint32 value,
 				      guint byte_order)
 {
+  if(cbuffer == NULL){
+    return;
+  }
+
   if(byte_order == AGS_BYTE_ORDER_BE){
     cbuffer[0] = (0xff & value);
     cbuffer[1] = (0xff00 & value) >> 8;
@@ -1429,6 +1541,10 @@ ags_buffer_util_char_buffer_write_s64(guchar *cbuffer,
 				      gint64 value,
 				      guint byte_order)
 {
+  if(cbuffer == NULL){
+    return;
+  }
+
   if(byte_order == AGS_BYTE_ORDER_BE){
     cbuffer[0] = (0xff & value);
     cbuffer[1] = (0xff00 & value) >> 8;
@@ -1470,6 +1586,10 @@ ags_buffer_util_char_buffer_write_float(guchar *cbuffer,
     GFloatIEEE754 ieee_float;
   }data;
 
+  if(cbuffer == NULL){
+    return;
+  }
+
   data.ieee_float.v_float = value;
   
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1505,6 +1625,10 @@ ags_buffer_util_char_buffer_write_double(guchar *cbuffer,
     GDoubleIEEE754 ieee_double;
   }data;
 
+  if(cbuffer == NULL){
+    return;
+  }
+
   data.ieee_double.v_double = value;
 
   if(byte_order == AGS_BYTE_ORDER_BE){
@@ -1550,6 +1674,10 @@ ags_buffer_util_char_buffer_write_complex(guchar *cbuffer,
 
   guint i;
 
+  if(cbuffer == NULL){
+    return;
+  }
+
   ags_complex_set(&(data.c_val),
 		  ags_complex_get(value));
 
@@ -1581,6 +1709,10 @@ ags_buffer_util_char_buffer_swap_bytes(guchar *cbuffer, guint word_size,
     
   guint i, j;
 
+  if(cbuffer == NULL){
+    return;
+  }
+
   if(word_size <= 1){
     return;
   }
